import shell from "shelljs";

import { handleLintStaged } from "./utils.js";
import { handleChakra, handleStyledComponents } from "./styles.js";
import { handleAuthModule } from "./customModules.js";
import { copyFromTemplatesToProject } from "./templateHandlers.js";

export const handleNextApp = ({ styles, auth, projectName }) => {
  shell.exec(
    `yarn create next-app --typescript ${projectName} &&
    cd ${projectName} &&
    yarn add -D prettier eslint-config-prettier lint-staged &&
    npx husky-init && yarn &&
    npx husky add .husky/pre-commit "npx lint-staged"
    `,
    () => {
      handleLintStaged(projectName);
      copyFromTemplatesToProject(["common", "next"], projectName);

      switch (styles) {
        default:
        case "styled":
          handleStyledComponents(projectName);
          break;

        case "chakra":
          handleChakra(projectName);
          break;
      }

      if (!!auth) {
        handleAuthModule(projectName);
      }
    }
  );
};
